# addonfactory-ucc-test

![PyPI](https://img.shields.io/pypi/v/splunk-add-on-ucc-modinput-test)
![Python](https://img.shields.io/pypi/pyversions/splunk-add-on-ucc-modinput-test.svg)

## What is AUT

It is a testing framework for functional tests for UCC based Splunk Add-ons.

## Usage

For full usage instructions, please visit the [documentation](https://splunk.github.io/addonfactory-ucc-test).

## Communication channels

If you are a Splunker use: https://splunk.enterprise.slack.com/archives/C081JT7R69Z

If you are a part of the community use: https://splunk-usergroups.slack.com/archives/C03SG3ZL4S1

## Contributing Guidelines

Go to [contributing Guidelines in the repo](docs/contributing.md) or [published version](https://splunk.github.io/addonfactory-ucc-test/contributing/).
